==> giada_0.15.4+ds1.orig.tar.xz: giada-0.15.4/src/gui/dialogs/browser/browserDir.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef GD_BROWSER_DIR_H
#define GD_BROWSER_DIR_H


#include "browserBase.h"


class gdBrowserDir : public gdBrowserBase
{
private:

	static void cb_load(Fl_Widget* w, void* p);
	static void cb_down(Fl_Widget* w, void* p);
	void cb_load();
	void cb_down();

public:

	gdBrowserDir(int x, int y, int w, int h, const std::string& title,
		const std::string& path, void (*callback)(void*));
};


#endif

==> giada_0.16.2.2+ds1.orig.tar.xz: giada-0.16.2.2/src/gui/dialogs/browser/browserDir.h <==
/* -----------------------------------------------------------------------------
 *
 * Giada - Your Hardcore Loopmachine
 *
 * -----------------------------------------------------------------------------
 *
 * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
 * Giada - Your Hardcore Loopmachine is free software: you can
 * redistribute it and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * Giada - Your Hardcore Loopmachine is distributed in the hope that it
 * will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Giada - Your Hardcore Loopmachine. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * -------------------------------------------------------------------------- */


#ifndef GD_BROWSER_DIR_H
#define GD_BROWSER_DIR_H


#include "browserBase.h"


namespace giada {
namespace v
{
class gdBrowserDir : public gdBrowserBase
{
public:

	gdBrowserDir(const std::string& title, const std::string& path, 
        std::function<void(void*)> cb);

private:

    static void cb_load(Fl_Widget* w, void* p);
    static void cb_down(Fl_Widget* w, void* p);
    void cb_load();
    void cb_down();
};
}} // giada::v::


#endif
